@@ -1,9 +1,8 @@
-/* $Id: gbsplay.c,v 1.96 2005/12/18 21:00:43 ranmachan Exp $
- *
+/*
  * gbsplay is a Gameboy sound player
  *
- * 2003-2005 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
- *                  Christian Garbs <mitch@cgarbs.de>
+ * 2003-2005,2008 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ *                       Christian Garbs <mitch@cgarbs.de>
  * Licensed under GNU GPL.
  */
 
@@ -79,6 +78,8 @@ static const char cfgfile[] = ".gbsplayrc";
 static char *sound_name = "oss";
 static char *sound_description;
 static plugout_open_fn  sound_open;
+static plugout_skip_fn  sound_skip;
+static plugout_io_fn    sound_io;
 static plugout_write_fn sound_write;
 static plugout_close_fn sound_close;
 
@@ -182,6 +183,12 @@ static regparm void swap_endian(struct gbhw_buffer *buf)
 	}
 }
 
+static regparm void iocallback(long cycles, uint32_t addr, uint8_t val, void *priv)
+{
+	if (sound_io)
+		sound_io(cycles, addr, val);
+}
+
 static regparm void callback(struct gbhw_buffer *buf, void *priv)
 {
 	if ((is_le_machine() && endian == PLUGOUT_ENDIAN_BIG) ||
@@ -314,6 +321,8 @@ static regparm long nextsubsong_cb(struct gbs *gbs, void *priv)
 	}
 
 	gbs_init(gbs, subsong);
+	if (sound_skip)
+		sound_skip(subsong);
 	return true;
 }
 
@@ -334,22 +343,23 @@ static regparm void usage(long exitcode)
 	        _("Usage: %s [option(s)] <gbs-file> [start_at_subsong [stop_at_subsong] ]\n"
 		  "\n"
 		  "Available options are:\n"
-		  "  -E  endian, b == big, l == little, n == native (%s)\n"
-		  "  -f  set fadeout (%ld seconds)\n"
-		  "  -g  set subsong gap (%ld seconds)\n"
-		  "  -h  display this help and exit\n"
-		  "  -l  loop mode\n"
-		  "  -o  select output plugin (%s)\n"
-		  "      'list' shows available plugins\n"
-		  "  -q  reduce verbosity\n"
-		  "  -r  set samplerate (%ldHz)\n"
-		  "  -R  set refresh delay (%ld milliseconds)\n"
-		  "  -t  set subsong timeout (%ld seconds)\n"
-		  "  -T  set silence timeout (%ld seconds)\n"
-		  "  -v  increase verbosity\n"
-		  "  -V  print version and exit\n"
-		  "  -z  play subsongs in shuffle mode\n"
-		  "  -Z  play subsongs in random mode (repetitions possible)\n"),
+		  "  -E        endian, b == big, l == little, n == native (%s)\n"
+		  "  -f        set fadeout (%ld seconds)\n"
+		  "  -g        set subsong gap (%ld seconds)\n"
+		  "  -h        display this help and exit\n"
+		  "  -l        loop mode\n"
+		  "  -o        select output plugin (%s)\n"
+		  "            'list' shows available plugins\n"
+		  "  -q        reduce verbosity\n"
+		  "  -r        set samplerate (%ldHz)\n"
+		  "  -R        set refresh delay (%ld milliseconds)\n"
+		  "  -t        set subsong timeout (%ld seconds)\n"
+		  "  -T        set silence timeout (%ld seconds)\n"
+		  "  -v        increase verbosity\n"
+		  "  -V        print version and exit\n"
+		  "  -z        play subsongs in shuffle mode\n"
+		  "  -Z        play subsongs in random mode (repetitions possible)\n"
+		  "  -1 to -4  mute a channel on startup\n"),
 	        myname,
 	        endian_str(endian),
 		fadeout,
@@ -372,11 +382,17 @@ static regparm void parseopts(int *argc, char ***argv)
 {
 	long res;
 	myname = *argv[0];
-	while ((res = getopt(*argc, *argv, "E:f:g:hlo:qr:R:t:T:vVzZ")) != -1) {
+	while ((res = getopt(*argc, *argv, "1234E:f:g:hlo:qr:R:t:T:vVzZ")) != -1) {
 		switch (res) {
 		default:
 			usage(1);
 			break;
+		case '1':
+		case '2':
+		case '3':
+		case '4':
+			gbhw_ch[res-'1'].mute ^= 1;
+			break;
 		case 'E':
 			if (strcasecmp(optarg, "b") == 0) {
 				endian = PLUGOUT_ENDIAN_BIG;
@@ -449,11 +465,15 @@ static regparm void handleuserinput(struct gbs *gbs)
 				gbs->subsong += gbs->songs;
 			}
 			gbs_init(gbs, gbs->subsong);
+			if (sound_skip)
+				sound_skip(gbs->subsong);
 			break;
 		case 'n':
 			gbs->subsong = get_next_subsong(gbs);
 			gbs->subsong %= gbs->songs;
 			gbs_init(gbs, gbs->subsong);
+			if (sound_skip)
+				sound_skip(gbs->subsong);
 			break;
 		case 'q':
 		case 27:
@@ -606,6 +626,8 @@ static regparm void select_plugin(void)
 	}
 
 	sound_open = plugout->open;
+	sound_skip = plugout->skip;
+	sound_io = plugout->io;
 	sound_write = plugout->write;
 	sound_close = plugout->close;
 	sound_description = plugout->description;
@@ -648,6 +670,7 @@ int main(int argc, char **argv)
 		exit(1);
 	}
 
+	gbhw_setiocallback(iocallback, NULL);
 	gbhw_setcallback(callback, NULL);
 	gbhw_setrate(rate);
 
@@ -687,6 +710,8 @@ int main(int argc, char **argv)
 	gbhw_setbuffer(&buf);
 	gbs_set_nextsubsong_cb(gbs, nextsubsong_cb, NULL);
 	gbs_init(gbs, gbs->subsong);
+	if (sound_skip)
+		sound_skip(gbs->subsong);
 	printinfo(gbs);
 	tcgetattr(STDIN_FILENO, &ts);
 	ots = ts;
