@@ -1,5 +1,4 @@
-/* $Id: plugout.c,v 1.4 2005/08/06 21:33:16 ranmachan Exp $
- *
+/*
  * gbsplay is a Gameboy sound player
  *
  * 2003-2005 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
@@ -18,22 +17,36 @@
 #ifdef PLUGOUT_DEVDSP
 extern const struct output_plugin plugout_devdsp;
 #endif
+#ifdef PLUGOUT_ALSA
+extern const struct output_plugin plugout_alsa;
+#endif
 #ifdef PLUGOUT_NAS
 extern const struct output_plugin plugout_nas;
 #endif
 #ifdef PLUGOUT_STDOUT
 extern const struct output_plugin plugout_stdout;
 #endif
+#ifdef PLUGOUT_MIDI
+extern const struct output_plugin plugout_midi;
+#endif
 
-static const struct output_plugin *plugouts[] = {
+typedef /*@null@*/ const struct output_plugin* output_plugin_const_t;
+
+static output_plugin_const_t plugouts[] = {
 #ifdef PLUGOUT_NAS
 	&plugout_nas,
 #endif
 #ifdef PLUGOUT_DEVDSP
 	&plugout_devdsp,
 #endif
+#ifdef PLUGOUT_ALSA
+	&plugout_alsa,
+#endif
 #ifdef PLUGOUT_STDOUT
 	&plugout_stdout,
+#endif
+#ifdef PLUGOUT_MIDI
+	&plugout_midi,
 #endif
 	NULL
 };
@@ -52,7 +65,7 @@ regparm void plugout_list_plugins(void)
 	for (idx = 0; plugouts[idx] != NULL; idx++) {
 		printf("%s\t- %s\n", plugouts[idx]->name, plugouts[idx]->description);
 	}
-	puts("");
+	(void)puts("");
 }
 
 regparm const struct output_plugin* plugout_select_by_name(const char *name)
